#include "unitree_motor_serial_driver/unitree_motor_serial_driver.hpp"

namespace unitree_motor_serial_driver
{

MotorControlNode::MotorControlNode()
    : Node("unitree_motor_serial_driver"), serial_("/dev/ttyACM0")
{
    timer_ = this->create_wall_timer(
        std::chrono::milliseconds(1), std::bind(&MotorControlNode::control_motor, this));
}

void MotorControlNode::control_motor()
{
    MotorCmd cmd;
    MotorData data;

    cmd.motorType = MotorType::GO_M8010_6;
    data.motorType = MotorType::GO_M8010_6;
    cmd.mode = queryMotorMode(MotorType::GO_M8010_6, MotorMode::FOC);
    cmd.id = 0;
    cmd.q = 0.0; 
    cmd.dq = 0.0;
    cmd.kp = 0.0;
    cmd.kd = 0.0;
    cmd.tau = 0.0;

    serial_.sendRecv(&cmd, &data);

    RCLCPP_INFO(this->get_logger(), "\nMotor.q: %f\nMotor.temp: %d\nMotor.W: %f\nMotor.tau: %f\n",
                data.q, data.temp, data.dq, data.tau);
}

} // namespace unitree_motor_serial_driver

int main(int argc, char **argv)
{
    rclcpp::init(argc, argv);
    rclcpp::spin(std::make_shared<unitree_motor_serial_driver::MotorControlNode>());
    rclcpp::shutdown();
    return 0;
}